@@ -27,7 +27,7 @@ def Leave(GroupID):
 
 def GetFunds(GroupID):
     try:
-        response = Internal.CurrentCookie.delete(f"{Utils.EconomyURL}/groups/{GroupID}/currency/")
+        response = Internal.CurrentCookie.post(f"{Utils.EconomyURL}/groups/{GroupID}/currency/")
         return response.json()['robux']
     except:
         return response.json()
